@@ -34,17 +34,17 @@ class AudioView2 : public QWidget
     Q_OBJECT
     
 public:
-    explicit AudioView2(QWidget *parent = 0);
-    ~AudioView2();
+    explicit AudioView2(QWidget *parent = nullptr);
+    ~AudioView2() override;
 
     void setupAnalyzer();
 
-public slots:
+public Q_SLOTS:
     void enableDemo(bool enable);
     void update();
     
 protected:
-    void changeEvent(QEvent *e) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *e) override;
     
 private:
     Ui::AudioView2 *ui;
